<!-- Give high level context to this PR -->

## 🛠️ Changes proposed in this pull request

* <!-- List the main changes you've made -->

## 👀 Guidance to review

<!-- Help reviewers know where to focus their efforts, or flag controversial decisions -->
<!-- Add links and diagrams to explain decisions -->
<!-- Point out any **breaking changes** -->

## 🤖 AI declaration

<!-- Declare code where AI was used, and how you ensured its quality -->

## ✅ Checklist:

- [ ] This is the smallest, simplest solution to the problem
- [ ] I've read [our code standards](https://uktrade.github.io/matchbox/contributing/) and this code follows them  
- [ ] All new code is tested
- I've updated all relevant documentation (select all that apply)
    - [ ] API documentation (docstrings and indexes)
    - [ ] Tutorials
    - [ ] Developer docs
